MotionSpacing class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- borderRadiusButton → BorderRadius
-
no setter
- borderRadiusCard → BorderRadius
-
no setter
- borderRadiusCircle → BorderRadius
-
no setter
- borderRadiusInput → BorderRadius
-
no setter
- borderRadiusLg → BorderRadius
-
no setter
- borderRadiusMd → BorderRadius
-
no setter
- borderRadiusSm → BorderRadius
-
no setter
- borderRadiusXl → BorderRadius
-
no setter
- borderRadiusXs → BorderRadius
-
no setter
- horizontalLg → SizedBox
-
no setter
- horizontalMd → SizedBox
-
no setter
- horizontalSm → SizedBox
-
no setter
- horizontalXl → SizedBox
-
no setter
- horizontalXs → SizedBox
-
no setter
- horizontalXxl → SizedBox
-
no setter
- listItemPadding → EdgeInsets
-
no setter
- modalPadding → EdgeInsets
-
no setter
- sectionPadding → EdgeInsets
-
no setter
- verticalLg → SizedBox
-
no setter
- verticalMd → SizedBox
-
no setter
- verticalSm → SizedBox
-
no setter
- verticalXl → SizedBox
-
no setter
- verticalXs → SizedBox
-
no setter
- verticalXxl → SizedBox
-
no setter
Static Methods
-
all(
double value) → EdgeInsets -
only(
{double left = 0, double top = 0, double right = 0, double bottom = 0}) → EdgeInsets -
symmetric(
{double horizontal = 0, double vertical = 0}) → EdgeInsets
Constants
- cardPadding → const EdgeInsets
- inputPadding → const EdgeInsets
- lg → const double
- md → const double
- pagePadding → const EdgeInsets
- sm → const double
- space2 → const double
- space6 → const double
- space12 → const double
- space20 → const double
- space40 → const double
- space56 → const double
- space72 → const double
- xl → const double
- xs → const double
- xxl → const double
- xxxl → const double